@@ -1419,6 +1419,73 @@ class RosTopic(
     ) -> None:
         jsii.set(self, "replicationFactor", value)
 
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="tags")
+    def tags(self) -> typing.Optional[typing.List["RosTopic.TagsProperty"]]:
+        '''
+        :Property: tags: Tags to attach to instance. Max support 20 tags to add during create instance. Each tag with two properties Key and Value, and Key is required.
+        '''
+        return typing.cast(typing.Optional[typing.List["RosTopic.TagsProperty"]], jsii.get(self, "tags"))
+
+    @tags.setter
+    def tags(
+        self,
+        value: typing.Optional[typing.List["RosTopic.TagsProperty"]],
+    ) -> None:
+        jsii.set(self, "tags", value)
+
+    @jsii.data_type(
+        jsii_type="@alicloud/ros-cdk-kafka.RosTopic.TagsProperty",
+        jsii_struct_bases=[],
+        name_mapping={"key": "key", "value": "value"},
+    )
+    class TagsProperty:
+        def __init__(
+            self,
+            *,
+            key: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+            value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+        ) -> None:
+            '''
+            :param key: 
+            :param value: 
+            '''
+            self._values: typing.Dict[str, typing.Any] = {
+                "key": key,
+            }
+            if value is not None:
+                self._values["value"] = value
+
+        @builtins.property
+        def key(self) -> typing.Union[builtins.str, ros_cdk_core.IResolvable]:
+            '''
+            :Property: key: undefined
+            '''
+            result = self._values.get("key")
+            assert result is not None, "Required property 'key' is missing"
+            return typing.cast(typing.Union[builtins.str, ros_cdk_core.IResolvable], result)
+
+        @builtins.property
+        def value(
+            self,
+        ) -> typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]]:
+            '''
+            :Property: value: undefined
+            '''
+            result = self._values.get("value")
+            return typing.cast(typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]], result)
+
+        def __eq__(self, rhs: typing.Any) -> builtins.bool:
+            return isinstance(rhs, self.__class__) and rhs._values == self._values
+
+        def __ne__(self, rhs: typing.Any) -> builtins.bool:
+            return not (rhs == self)
+
+        def __repr__(self) -> str:
+            return "TagsProperty(%s)" % ", ".join(
+                k + "=" + repr(v) for k, v in self._values.items()
+            )
+
 
 @jsii.data_type(
     jsii_type="@alicloud/ros-cdk-kafka.RosTopicProps",
@@ -1433,6 +1500,7 @@ class RosTopic(
         "min_insync_replicas": "minInsyncReplicas",
         "partition_num": "partitionNum",
         "replication_factor": "replicationFactor",
+        "tags": "tags",
     },
 )
 class RosTopicProps:
@@ -1448,6 +1516,7 @@ class RosTopicProps:
         min_insync_replicas: typing.Optional[typing.Union[jsii.Number, ros_cdk_core.IResolvable]] = None,
         partition_num: typing.Optional[typing.Union[jsii.Number, ros_cdk_core.IResolvable]] = None,
         replication_factor: typing.Optional[typing.Union[jsii.Number, ros_cdk_core.IResolvable]] = None,
+        tags: typing.Optional[typing.Sequence[RosTopic.TagsProperty]] = None,
     ) -> None:
         '''Properties for defining a ``ALIYUN::KAFKA::Topic``.
 
@@ -1460,6 +1529,7 @@ class RosTopicProps:
         :param min_insync_replicas: 
         :param partition_num: 
         :param replication_factor: 
+        :param tags: 
         '''
         self._values: typing.Dict[str, typing.Any] = {
             "instance_id": instance_id,
@@ -1478,6 +1548,8 @@ class RosTopicProps:
             self._values["partition_num"] = partition_num
         if replication_factor is not None:
             self._values["replication_factor"] = replication_factor
+        if tags is not None:
+            self._values["tags"] = tags
 
     @builtins.property
     def instance_id(self) -> typing.Union[builtins.str, ros_cdk_core.IResolvable]:
@@ -1608,6 +1680,14 @@ class RosTopicProps:
         result = self._values.get("replication_factor")
         return typing.cast(typing.Optional[typing.Union[jsii.Number, ros_cdk_core.IResolvable]], result)
 
+    @builtins.property
+    def tags(self) -> typing.Optional[typing.List[RosTopic.TagsProperty]]:
+        '''
+        :Property: tags: Tags to attach to instance. Max support 20 tags to add during create instance. Each tag with two properties Key and Value, and Key is required.
+        '''
+        result = self._values.get("tags")
+        return typing.cast(typing.Optional[typing.List[RosTopic.TagsProperty]], result)
+
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
@@ -1676,6 +1756,7 @@ class Topic(
         "min_insync_replicas": "minInsyncReplicas",
         "partition_num": "partitionNum",
         "replication_factor": "replicationFactor",
+        "tags": "tags",
     },
 )
 class TopicProps:
@@ -1691,6 +1772,7 @@ class TopicProps:
         min_insync_replicas: typing.Optional[typing.Union[jsii.Number, ros_cdk_core.IResolvable]] = None,
         partition_num: typing.Optional[typing.Union[jsii.Number, ros_cdk_core.IResolvable]] = None,
         replication_factor: typing.Optional[typing.Union[jsii.Number, ros_cdk_core.IResolvable]] = None,
+        tags: typing.Optional[typing.Sequence[RosTopic.TagsProperty]] = None,
     ) -> None:
         '''Properties for defining a ``ALIYUN::KAFKA::Topic``.
 
@@ -1703,6 +1785,7 @@ class TopicProps:
         :param min_insync_replicas: Property minInsyncReplicas: The minimum number of ISR sync replicas. This parameter can only be specified if the LocalTopic value is true. The value must be less than the number of Topic copies. The number of synchronous replicas is limited to 1~3.
         :param partition_num: Property partitionNum: The number of partitions in the topic. Valid values: 1 to 48 We recommend that you set the number of partitions to a multiple of 6 to reduce the risk of data skew.Note:For special requirements,submit a ticket.
         :param replication_factor: Property replicationFactor: The number of copies of the topic. This parameter can only be specified if the LocalTopic value is true. The number of copies is limited to 1~3. Note When the number of replicas is 1, there is a risk of data loss. Please set it carefully.
+        :param tags: Property tags: Tags to attach to instance. Max support 20 tags to add during create instance. Each tag with two properties Key and Value, and Key is required.
         '''
         self._values: typing.Dict[str, typing.Any] = {
             "instance_id": instance_id,
@@ -1721,6 +1804,8 @@ class TopicProps:
             self._values["partition_num"] = partition_num
         if replication_factor is not None:
             self._values["replication_factor"] = replication_factor
+        if tags is not None:
+            self._values["tags"] = tags
 
     @builtins.property
     def instance_id(self) -> typing.Union[builtins.str, ros_cdk_core.IResolvable]:
@@ -1838,6 +1923,15 @@ class TopicProps:
         result = self._values.get("replication_factor")
         return typing.cast(typing.Optional[typing.Union[jsii.Number, ros_cdk_core.IResolvable]], result)
 
+    @builtins.property
+    def tags(self) -> typing.Optional[typing.List[RosTopic.TagsProperty]]:
+        '''Property tags: Tags to attach to instance.
+
+        Max support 20 tags to add during create instance. Each tag with two properties Key and Value, and Key is required.
+        '''
+        result = self._values.get("tags")
+        return typing.cast(typing.Optional[typing.List[RosTopic.TagsProperty]], result)
+
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
